#include "MainWindow.h"

#include <QMenu>
#include <QMenuBar>
#include <QToolBar>
#include <QStatusBar>
#include <QIcon>
#include <QPixmap>
#include <QDockWidget>

#include "AboutDialog.h"

MainWindow::MainWindow() : QMainWindow(NULL) {
  resize(600, 400);
  setWindowTitle("MainWindow");

  InitActions();
  InitMenuBar();
  InitToolBar();
  InitStatusBar();

  painterWidget = new PainterWidget(this);
  setCentralWidget(painterWidget);

  QDockWidget* dock = new QDockWidget("Log Window", this);
  log = new QTextEdit(this);
  dock->setWidget(log);
  dock->setMaximumHeight(150);
  addDockWidget(Qt::BottomDockWidgetArea, dock);

  show();
}

void MainWindow::InitActions() {
  //Menu "File"
  actFileOpen = new QAction(QIcon("open.png"), "&Open", this);
  connect(actFileOpen, SIGNAL(triggered()), this, SLOT(OnMenuFileOpen()));
  actFileOpen->setStatusTip("Open file and load data");
  actFileOpen->setToolTip("Open file");
  
  actFileExit = new QAction(QIcon("exit.png"), "E&xit", this);
  connect(actFileExit, SIGNAL(triggered()), this, SLOT(OnMenuFileExit()));
  actFileExit->setStatusTip("Exit this app");
  actFileExit->setToolTip("Exit app");
  //Menu "View"
  actViewToolbar = new QAction("&Toolbar", this);
  connect(actViewToolbar, SIGNAL(triggered()), this, SLOT(OnMenuViewToolbar()));
  actViewToolbar->setCheckable(true);
  actViewToolbar->setChecked(true);
  
  actViewStatusbar = new QAction("&Statusbar", this);
  connect(actViewStatusbar, SIGNAL(triggered()), this, SLOT(OnMenuViewStatusbar()));
  actViewStatusbar->setCheckable(true);
  actViewStatusbar->setChecked(true);
  //Menu "Help"
  actHelpAbout = new QAction(QIcon("about.png"), "&About", this);
  connect(actHelpAbout, SIGNAL(triggered()), this, SLOT(OnMenuHelpAbout()));
}

void MainWindow::InitMenuBar() {
  QMenu *menuFile = new QMenu("File");
  menuFile->addAction(actFileOpen);
  menuFile->addSeparator();
  menuFile->addAction(actFileExit);
  menuBar()->addMenu(menuFile);

  QMenu *menuView = new QMenu("View");
  menuView->addAction(actViewToolbar);
  menuView->addAction(actViewStatusbar);
  menuBar()->addMenu(menuView);

  QMenu *menuHelp = new QMenu("Help");
  menuHelp->addAction(actHelpAbout);
  menuBar()->addMenu(menuHelp);
}

void MainWindow::InitToolBar() {
  toolBar = new QToolBar(this);
  toolBar->setIconSize(QSize(32, 32));
  toolBar->addAction(actFileOpen);
  toolBar->addSeparator();
  toolBar->addAction(actFileExit);
  addToolBar(toolBar);
}

void MainWindow::InitStatusBar() {
  statusBar = new QStatusBar(this);
  setStatusBar(statusBar);
  statusBar->showMessage("Welcome");
  statusBar->setStatusTip("StatusBar");
}

void MainWindow::OnMenuFileOpen() {
}

void MainWindow::OnMenuFileExit() {
  close();
}

void MainWindow::OnMenuViewToolbar() {
  toolBar->setVisible(actViewToolbar->isChecked());
}

void MainWindow::OnMenuViewStatusbar() {
  statusBar->setVisible(actViewStatusbar->isChecked());
}

void MainWindow::OnMenuHelpAbout() {
  AboutDialog dlg(this);
  dlg.exec();
}
